# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [flash-scheduler@0.1.2-alpha.1] - 2026-02-10


### Features

- add scheduler feature ([015ade1])


### Bug Fixes

- resolve all deprecation and pytest warnings ([8ac9385])


### Refactoring

- resolve ty check errors ([7fb7ca8])
- comprehensive ruff linting fixes ([f897869])
- comprehensive ruff linting fixes ([6246878])
- ruff linting and formatting fixes ([2fef995])

## [flash-scheduler@0.1.1-alpha.1] - 2026-01-18


### Features

- initial commit with flash_db. ([39f3a23])

